@@ -1,5 +1,7 @@
 import re
 
+from data_catalog_dcat_validator.models.dataset import DatasetModel
+
 
 def validate_bucket_name(name):
     ''' Validates that the bucket name consists of lower case letters and numbers, words separated with '-', and
@@ -13,3 +15,9 @@ def validate_bucket_name(name):
         raise NameError(f"Illegal bucket name ({name}): "
                         "Must be lower case letters or numbers, words separated with '-', "
                         "and cannot start or end with '-')")
+
+
+def validate_metadata(metadata: dict):
+    validator = DatasetModel(metadata)
+    validator.validate()
+    validator.error_report()
